<?php

namespace Restaurant\Table\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Restaurant\Table\Http\Requests\TableRequest;
use Restaurant\Table\Interfaces\TableRepositoryInterface;
use Restaurant\Table\Models\Table;
use Restaurant\Table\Forms\Table as Form;

/**
 * APIController  class for table.
 */
class TableAPIController extends BaseController
{

    /**
     * Initialize table resource controller.
     *
     * @param type TableRepositoryInterface $table
     *
     * @return null
     */
    public function __construct(TableRepositoryInterface $table)
    {
        parent::__construct();
        $this->repository = $table;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Restaurant\Table\Repositories\Criteria\TableResourceCriteria::class);
    }

    /**
     * Display a list of table.
     *
     * @return Response
     */
    public function index(TableRequest $request)
    {
        return $this->repository
            ->setPresenter(\Restaurant\Table\Repositories\Presenter\TablePresenter::class)
            ->paginate();
    }

    /**
     * Display table.
     *
     * @param Request $request
     * @param Model   $table
     *
     * @return Response
     */
    public function show(TableRequest $request, Table $table)
    {
        return $table->setPresenter(\Restaurant\Table\Repositories\Presenter\TableListPresenter::class);
        ;
    }

    /**
     * Create new table.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(TableRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('table::table.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('table/table/' . $table->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('table/table');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the table.
     *
     * @param Request $request
     * @param Model   $table
     *
     * @return Response
     */
    public function update(TableRequest $request, Table $table)
    {
        try {
            $data = $request->all();

            $table->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('table::table.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('table/table/' . $table->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('table/table/' . $table->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the table.
     *
     * @param Model   $table
     *
     * @return Response
     */
    public function destroy(TableRequest $request, Table $table)
    {
        try {
            $table->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('table::table.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('table/table/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('table/table/' . $table->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
